Encoder

Struct Encoder 

pub struct Encoder<FS: FileSystem = NativeFileSystem> { /* private fields */ }
Encoder which can archive a given path as a NAR file.

The encoder will read the data to archive using its FileSystem implementation. By default, it reads the host filesystem using std::fs.

Implementations

Source

impl Encoder<NativeFileSystem>

pub fn new<P: AsRef<Path>>(path: P) -> Result<Self, NarError>

Create a new encoder for file hierarchy at the given path using default filesystem implementation.

Errors

Returns an error if the path is not valid UTF-8.

pub fn builder<P: AsRef<Path>>(path: P) -> EncoderBuilder<P>

Create a builder for this encoder that can take additional options.

use nix_nar::{Encoder, NativeFileSystem};
let mut enc = Encoder::builder("./test-data/")
    .internal_buffer_size(2048)
    .filesystem(NativeFileSystem {})
    .build().unwrap();
let mut nar = File::create("output2.nar")?;
io::copy(&mut enc, &mut nar)?;
Source

impl<FS: FileSystem> Encoder<FS>

pub fn new_with_filesystem<P: AsRef<Path>>( path: P, fs: FS, ) -> Result<Self, NarError>

Create a new encoder for file hierarchy at the given path and provided filesystem implementation.

Errors

Returns an error if the path is not valid UTF-8.

pub fn pack<P: AsRef<Path>>(&mut self, dst: P) -> Result<(), NarError>

Archive to the given path.

This is equivalent to creating the file, and io::copying to it.

Errors

Returns an error if the path already exists or an I/O error occurs.